import util from '@/static/js/util.js'
import storage from '@/static/js/storage.js'
import service from '@/static/js/service.js'

//获取授权参数

function getHeader() {
	let header = {
		'content-type': 'application/json'
	};
	let tokenInfo = storage.getTokenInfo();
	if (tokenInfo) {
		header['token'] = tokenInfo;
	}
	return header;
}

// #ifdef H5
const locDomain = '/index/index'
const uploadApi = '/index/index/upload/uploadEditor'
const locImg = '/static/images/'
const policyUrl='https://hnmenyou.cn/userprivacy/index.html#/'
// #endif

// #ifdef APP-PLUS
const locImg = '/static/images/'
// const locDomain = 'https://hnmenyou.cn/index'
// const uploadApi = 'https://hnmenyou.cn/index/upload/uploadEditor'
// const policyUrl='https://hnmenyou.cn/userprivacy/index.html#/'

//yjx new server
// const locDomain = 'http://116.62.14.160/index'
// const uploadApi = 'http://116.62.14.160/index/upload/uploadEditor'
// const policyUrl='http://116.62.14.160/userprivacy/index.html#/'

//yjx official server
const locDomain = 'http://121.43.111.232/index'
const uploadApi = 'http://121.43.111.232/index/upload/uploadEditor'
const policyUrl='http://121.43.111.232/userprivacy/index.html#/'
// #endif

//检查结果 
function checkResult(url, res) {
	if (res.data.code != 1) {
		if (res.data.code == 0) {
			util.showToast(res.data.msg || '接口调用失败')
			if (res.data.msg == 'token不存在') {
				uni.reLaunch({
					url: '/pages/login/login'
				})
			}
		}
		//token过期
		if (res.data.code == 404) {
			uni.clearStorageSync();
			uni.reLaunch({
				url: "/pages/login/login"
			})
		}

		if (res.data.code == 401) {
			util.showToast(res.data.msg)
		}

		if (res.data.code == 500) {
			util.showToast("服务异常，联系管理员")
		}
		return false;
	}
	return true;
}
//http请求
const http = {
	//api域名
	locDomain,
	uploadApi,
	locImg,
	policyUrl,
	//请求
	async request(method, url, params, loadingText) {
		url = locDomain + url
		let res = await request(method, url, params, loadingText);
		return res;
	},

	//上传文件
	async upload(url, filePath, params, loadingText) {
		url = uploadApi; //完整请求路径
		let res = await upload(url, filePath, params, loadingText);
		console.info(res)
	},
}

//执行请求事件
function request(method, url, params, loadingText) {
	return new Promise((resolve, reject) => {
		//加载中效果
		if (loadingText) {
			uni.showLoading({
				title: loadingText,
				mask: true
			})
		}
		let header = getHeader();
		uni.request({
			url: url,
			data: {
				...params,
			} || {},
			method: method,
			header: header,
			success(res) {
				loadingText && uni.hideLoading();
				if (checkResult(url, res)) {
					//访问成功
					resolve(res.data);
				} else {
					//访问失败
					reject(res);
				}

			},
			fail(err) {
				//访问失败
				loadingText && uni.hideLoading();
				reject(err);
			}
		})
	})
}

//上传文件
function upload(url, filePath, params, loadingText) {
	return new Promise((resolve, reject) => {
		//加载中效果
		if (loadingText) {
			uni.showLoading({
				title: loadingText,
				mask: true
			})
		}
		let header = getHeader();
		// header['Content-Type'] = "multipart/form-data";
		uni.uploadFile({
			url: url,
			filePath: filePath,
			name: 'image',
			formData: params || {},
			// method: 'POST',
			header: header,
			success(res) {
				loadingText && uni.hideLoading();
				console.info(res.data)
				// res.data = JSON.parse(res.data);
				// res.success = checkResult(url, res);
				resolve(res);
			},
			fail(err) {
				loadingText && uni.hideLoading();
				// uni.showToast({
				// 	title: '接口异常',
				// 	icon: 'none'
				// })
				console.log(url || '', err);
				reject(err);
			}
		})
	})
}

export default http;