//缓存关键字
// const storageKey = 'BITP_';
//缓存管理
const storage = {
	//获取key全名称
	getFullKey: (key) =>  key,
	//设置缓存(异步)
	set(key, value) {
		if (value) {
			uni.setStorage({
				key: storage.getFullKey(key),
				data: value
			})
		} else {
			storage.remove(key)
		}
	},
	//获取缓存(异步)
	get(key, func) {
		uni.getStorage({
			key: storage.getFullKey(key),
			success(res) {
				func(res.data)
			}
		})
	},
	//移除缓存(异步)
	remove(key) {
		uni.removeStorage({
			key: storage.getFullKey(key)
		})
	},
	//获取缓存(异步)
	getAll(func) {
		uni.getStorageInfo({
			success(res) {
				func(res)
			}
		})
	},
	//设置缓存(同步)
	setSync: (key, value) => {
		if (value) {
			uni.setStorageSync(storage.getFullKey(key), value)
		} else {
			storage.removeSync(key);
		}
	},
	//获取缓存(同步)
	getSync: (key) => uni.getStorageSync(storage.getFullKey(key)),
	//移除缓存(同步)
	removeSync: (key) => uni.removeStorageSync(storage.getFullKey(key)),
	//获取所有(同步)
	getAllSync: () => uni.getStorageInfoSync(),

	//获取用户是否走完登录流程
	getLoginComplate: () => storage.getSync('loginComplate'),
	setLoginComplate: () => storage.setSync('loginComplate',true),
	
	getOpenIdKey: () => storage.getSync('openIdKey'),
	//设置用户openIdKey信息
	setOpenIdKey: (openIdKey) => storage.setSync('openIdKey', openIdKey),

	//获取用户openIdKey信息
	getOpenIdKey: () => storage.getSync('openIdKey'),
	//设置用户openIdKey信息
	setOpenIdKey: (openIdKey) => storage.setSync('openIdKey', openIdKey),

	//获取用户token信息
	getTokenInfo: () => storage.getSync('tokenInfo'),
	//设置用户token信息
	setTokenInfo: (tokenInfo) => storage.setSync('tokenInfo', tokenInfo),

	//获取用户信息
	getUserInfo: () => storage.getSync('userInfo'),
	//设置用户信息
	setUserInfo: (userInfo) => storage.setSync('userInfo', userInfo),

	//发布选择团队和用户
	setDeptAndUsers:(deptAndUsers) => storage.setSync('deptAndUsers', deptAndUsers),
	//获取发布选择团队和用户
	getDeptAndUsers: () => storage.getSync('deptAndUsers'),
	
	// 设置游客状态
	setGuestStatus: (isGuest) => storage.setSync('guestStatus', isGuest),
	
	// 获取游客状态
	getGuestStatus: () => storage.getSync('guestStatus'),
}

export default storage;
