/* *
 * 通用公共js库，常量值和通用函数
 */
import service from '@/static/js/service.js'
import storage from '@/static/js/storage.js'

const util = {
	//调起支付  payCode :0-支付宝,1-微信,2-余额
	requestPayment(provider, orderInfo) {
		return new Promise((resolve, reject) => {
			if (!provider) {
				uni.showToast({
					title: '参数错误'
				});
				resolve({
					success: false,
					msg: '参数错误'
				});
				return;
			}
			// #ifndef APP-PLUS
			uni.showToast({
				title: '当前仅支持微信支付，请前往App完成支付'
			});
			resolve({
				success: false,
				msg: '当前仅支持微信支付，请前往App完成支付'
			});
			return;
			// #endif
			let param = {
				provider,
				'orderInfo': orderInfo,
			}
			uni.requestPayment({
				provider,
				'orderInfo': orderInfo,
				success(res1) {
					res1.success = res1.errMsg == 'requestPayment:ok';
					resolve(res1);
				},
				fail(res1) {
					res1.success = false
					resolve(res1);
				}
			});
		})
	},
	statusPayment(weixin, alipay, bank) {
		let status = false
		if (weixin == 'true') {
			status = true
		} else {
			status = false
		}
		if (alipay == 'true') {
			status = true
		} else {
			status = false
		}
		if (bank == 'true') {
			status = true
		} else {
			status = false
		}
		return status;
	},
	getDistance(lat1, lng1, lat2, lng2) {
		lat1 = lat1 || 0;
		lng1 = lng1 || 0;
		lat2 = lat2 || 0;
		lng2 = lng2 || 0;

		var rad1 = lat1 * Math.PI / 180.0;
		var rad2 = lat2 * Math.PI / 180.0;
		var a = rad1 - rad2;
		var b = lng1 * Math.PI / 180.0 - lng2 * Math.PI / 180.0;
		var r = 6378137;
		var distance = r * 2 * Math.asin(Math.sqrt(Math.pow(Math.sin(a / 2), 2) + Math.cos(rad1) * Math.cos(rad2) *
			Math.pow(Math.sin(b / 2), 2)));
		return distance;
	},
	//位置信息
	userLocation() {
		return new Promise(function(resolve, reject) {
			uni.getSetting({
				success: (event) => {
					//判断当前是否获得授权，如果没有就去获得授权，如果获得授权，就直接获取当前地理位置
					if (!event.authSetting['scope.userLocation']) {
						var _this = this;
						uni.authorize({
							scope: 'scope.userLocation',
							success(res) { //1.1 允许授权
								resolve('success')
							},
							fail() { //1.2 拒绝授权
								uni.showModal({
									content: '检测到您没打开获取信息功能权限，是否去设置打开？',
									confirmText: "确认",
									cancelText: '取消',
									success: (res) => {
										if (res.confirm) {
											uni.openSetting({
												success: (res) => {
													resolve(
														'success'
													)
												}
											})
										}
									}
								})
							}
						})
					} else {
						resolve('success')
					}
				}
			});
		});
	},
	// 字符串加密
	toCode(str) {
		let key = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
		let l = key.length; //获取密钥的长度
		let a = key.split(""); //把密钥字符串转换为字符数组
		let s = "",
			b, b1, b2, b3; //定义临时变量
		for (let i = 0; i < str.length; i++) { //遍历字符串
			b = str.charCodeAt(i); //逐个提取每个字符，并获取Unicode编码值
			b1 = b % l; //求Unicode编码值得余数
			b = (b - b1) / l; //求最大倍数
			b2 = b % l; //求最大倍数的于是
			b = (b - b2) / l; //求最大倍数
			b3 = b % l; //求最大倍数的余数
			s += a[b3] + a[b2] + a[b1]; //根据余数值映射到密钥中对应下标位置的字符
		}
		return s; //返回这些映射的字符
	},
	//显示成功提示
	showSuccess(title) {
		uni.showToast({
			title: title || '操作成功',
			position: "bottom"
		})
	},
	//计算服务距离
	distance(la1, lo1, la2, lo2) {
		var La1 = la1 * Math.PI / 180.0;
		var La2 = la2 * Math.PI / 180.0;
		var La3 = La1 - La2;
		var Lb3 = lo1 * Math.PI / 180.0 - lo2 * Math.PI / 180.0;
		var s = 2 * Math.asin(Math.sqrt(Math.pow(Math.sin(La3 / 2), 2) + Math.cos(La1) * Math.cos(La2) * Math.pow(
			Math.sin(Lb3 / 2), 2)));
		s = s * 6378137; //地球半径 
		s = Math.round(s);
		return s;
	},
	//单位换算
	kmUnit(m) {
		var v;
		if (typeof m === 'number' && !isNaN(m)) {
			if (m >= 1000) {
				v = (m / 1000).toFixed(2) + 'km'
			} else {
				v = m + 'm'
			}
		} else {
			v = '0m'
		}
		return v;
	},
	//显示复制成功提示
	setClipboardData(title) {
		uni.showToast({
			title: title || '复制成功',
			icon: 'none',
			position: "bottom"
		})
	},
	//显示错误提示
	showToast(title) {
		uni.showToast({
			title: title || '网络异常，请稍后重试',
			icon: 'none',
			position: "bottom"
		})
	},
	//显示加载中提示
	showLoading(title) {
		uni.showLoading({
			title: title,
			mask: true,
			position: "bottom"
		})
	},
	//保留两位有小数数字
	demicalInput(value) {
		value = value || '';
		value = value.replace(/[^\d^\.]+/g, '');
		if (value.indexOf(".") < 0 && value != "") {
			value = parseFloat(value);
		} else if (value.indexOf(".") == 0) {
			// console.log('首位小数点情况')
			value = value.replace(/[^$#$]/g, "0.");
			value = value.replace(/\.{2,}/g, ".");
		} else if (!(/^(\d?)+(\.\d{0,2})?$/.test(value))) {
			//去掉最后一位
			value = value.substring(0, value.length - 1)
		}
		return value;
	},
	//获取image集合
	getImageList(imgStr, serviceImgUrl) {
		serviceImgUrl = serviceImgUrl || '';
		let array = imgStr ? imgStr.split('>>') : [];
		for (var i = 0; i < array.length; i++) {
			array[i] = serviceImgUrl + array[i]
		}
		return array;
	},
	//是否为空字符串
	isEmpty(input) {
		input = input || "";
		if (input == "") return true;
		let regu = "^[ ]+$";
		let re = new RegExp(regu);
		return re.test(input);
	},
	//验证手机号码 [可匹配"(+86)013325656352"，括号可以省略，+号可以省略，(+86)可以省略，11位手机号前的0可以省略；11位手机号第二位数可以是3-9中的任意一个]
	isMobilePhoneNumber(input) {
		let regex = /^((\+)?86|((\+)?86)?)0?1[3-9]\d{9}$/;
		return input.match(regex);
	},
	//验证身份证号 [可验证一代或二代身份证]
	isIDCard(input) {
		input = input.toUpperCase();
		//验证身份证号码格式 [一代身份证号码为15位的数字；二代身份证号码为18位的数字或17位的数字加字母X]  
		if (!(/(^\d{15}$)|(^\d{17}([0-9]|X)$)/i.test(input))) {
			return false;
		}
		//验证省份  
		let arrCity = {
			11: '北京',
			12: '天津',
			13: '河北',
			14: '山西',
			15: '内蒙古',
			21: '辽宁',
			22: '吉林',
			23: '黑龙江 ',
			31: '上海',
			32: '江苏',
			33: '浙江',
			34: '安徽',
			35: '福建',
			36: '江西',
			37: '山东',
			41: '河南',
			42: '湖北',
			43: '湖南',
			44: '广东',
			45: '广西',
			46: '海南',
			50: '重庆',
			51: '四川',
			52: '贵州',
			53: '云南',
			54: '西藏',
			61: '陕西',
			62: '甘肃',
			63: '青海',
			64: '宁夏',
			65: '新疆',
			71: '台湾',
			81: '香港',
			82: '澳门',
			91: '国外'
		};
		if (arrCity[parseInt(input.substr(0, 2))] == null) {
			return false;
		}
		//验证出生日期  
		let regBirth, birthSplit, birth;
		let len = input.length;
		if (len == 15) {
			regBirth = new RegExp(/^(\d{6})(\d{2})(\d{2})(\d{2})(\d{3})$/);
			birthSplit = input.match(regBirth);
			birth = new Date('19' + birthSplit[2] + '/' + birthSplit[3] + '/' + birthSplit[4]);
			if (!(birth.getYear() == Number(birthSplit[2]) && (birth.getMonth() + 1) == Number(birthSplit[3]) &&
					birth.getDate() ==
					Number(birthSplit[4]))) {
				return false;
			}
			return true;
		} else if (len == 18) {
			regBirth = new RegExp(/^(\d{6})(\d{4})(\d{2})(\d{2})(\d{3})([0-9]|X)$/i);
			birthSplit = input.match(regBirth);
			birth = new Date(birthSplit[2] + '/' + birthSplit[3] + '/' + birthSplit[4]);
			if (!(birth.getFullYear() == Number(birthSplit[2]) && (birth.getMonth() + 1) == Number(birthSplit[3]) &&
					birth.getDate() ==
					Number(birthSplit[4]))) {
				return false;
			}
			//验证校验码  
			let valnum;
			let arrInt = new Array(7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2);
			let arrCh = new Array('1', '0', 'X', '9', '8', '7', '6', '5', '4', '3', '2');
			let nTemp = 0,
				i;
			for (i = 0; i < 17; i++) {
				nTemp += input.substr(i, 1) * arrInt[i];
			}
			valnum = arrCh[nTemp % 11];
			if (valnum != input.substr(17, 1)) {
				return false;
			}
			return true;
		}
		return false;
	},
	//验证特殊字符
	testSpecialCharacters(str) {
		var re = /^([\u4E00-\u9FA5]|\w)*$/;
		return re.test(str)
	},

}

export default util;